.. _dataimport_module:

:mod:`cubicweb.dataimport`
==========================

.. automodule:: cubicweb.dataimport

    Utilities
    ---------

    .. autofunction:: count_lines

    .. autofunction:: ucsvreader_pb

    .. autofunction:: ucsvreader

    .. autofunction:: callfunc_every

    Object Stores
    -------------

    .. autoclass:: RQLObjectStore
        :show-inheritance:
        :members:

    .. autoclass:: NoHookRQLObjectStore
        :show-inheritance:
        :members:
